@@ -100,13 +100,13 @@ bool reloadShaders(std_srvs::Empty::Request& /*unused*/, std_srvs::Empty::Respon
   return true;
 }
 
-VisualizerApp::VisualizerApp() : app_(nullptr), continue_timer_(nullptr), frame_(nullptr)
+VisualizerApp::VisualizerApp() : continue_timer_(nullptr), frame_(nullptr)
 {
 }
 
 void VisualizerApp::setApp(QApplication* app)
 {
-  app_ = app;
+  Q_UNUSED(app);
 }
 
 bool VisualizerApp::init(int argc, char** argv)
@@ -202,7 +202,6 @@ bool VisualizerApp::init(int argc, char** argv)
       RenderSystem::forceNoStereo();
 
     frame_ = new VisualizationFrame();
-    frame_->setApp(this->app_);
     if (!help_path.empty())
     {
       frame_->setHelpPath(QString::fromStdString(help_path));
